@@ -6,6 +6,17 @@ import xml.etree.ElementTree as et
 
 from decimal import Decimal
 
+# Python 2, 3 intercompatibility
+try:
+    basestring
+except NameError:
+    basestring = str
+
+try:
+    long
+except NameError:
+    long = int
+
 def compose(data, root, arrays={}):
     root_e = compose_element(root, data, arrays)
     return et.tostring(root_e, 'utf-8')
@@ -21,8 +32,8 @@ def compose_element(key, value, arrays={}):
         e.attrib['type'] = 'decimal'
         e.text = str(value)
     elif isinstance(value, datetime.datetime):
-        e.attrib['type'] = 'timestamp'
-        e.text = value.strftime("%Y-%m-%d %H:%M:%S %z")
+        e.attrib['type'] = 'dateTime'
+        e.text = value.replace(microsecond=0).isoformat()
     elif value is None:
         e.attrib['nil'] = 'true'
     elif isinstance(value, collections.Sequence):
@@ -31,7 +42,7 @@ def compose_element(key, value, arrays={}):
         for x in value:
             e.append(compose_element(e_key, x, arrays))
     elif isinstance(value, collections.Mapping):
-        for key, value in value.iteritems():
+        for key, value in value.items():
             e.append(compose_element(key, value, arrays))
     else:
         raise TypeError("Value %r has unsupported type %s" % (value, type(value)))
