@@ -10,11 +10,11 @@ try:
     # Python 3
     from urllib import parse as urlparse
     from urllib.parse import urlencode
-    from http.client import HTTPConnection
+    from http.client import HTTPConnection, HTTPException
 except ImportError:
     # Python 2
     import urlparse
-    from httplib import HTTPConnection
+    from httplib import HTTPConnection, HTTPException
     from urllib import urlencode
 
 
@@ -38,7 +38,6 @@ class Connection(object):
 
     def request(self, method, endpoint, qargs={}, data=None):
         path = self.format_path(endpoint, qargs)
-        conn = HTTPConnection('%s.myinsales.ru:80' % self.account, timeout=self.response_timeout)
         auth = b64encode(u"{0}:{1}".format(self.api_key, self.password).encode('utf-8')).decode('utf-8')
         headers = {
             'Authorization': 'Basic {0}'.format(auth),
@@ -48,17 +47,18 @@ class Connection(object):
         done = False
         while not done:
             try:
+                conn = HTTPConnection('%s.myinsales.ru:80' % self.account,
+                                      timeout=self.response_timeout)
                 conn.request(method, path, headers=headers, body=data)
-            except (socket.gaierror, socket.timeout):
+                resp = conn.getresponse()
+                body = resp.read()
+            except (socket.gaierror, socket.timeout, HTTPException):
                 if self.retry_on_socket_error:
                     time.sleep(self.retry_timeout)
                     continue
                 else:
                     raise
 
-            resp = conn.getresponse()
-            body = resp.read()
-
             if resp.status == 503 and self.retry_on_503:
                 time.sleep(self.retry_timeout)
             else:
@@ -67,18 +67,23 @@ class Connection(object):
         if 200 <= resp.status < 300:
             return body
         else:
-            raise ApiError("%s request to %s returned: %s\n%s" % 
+            raise ApiError("%s request to %s returned: %s\n%s" %
                            (method, path, resp.status, body), resp.status)
 
     def format_path(self, endpoint, qargs):
         for key, val in qargs.items():
             if isinstance(val, datetime.datetime):
-                qargs[key] = val.strftime('%Y-%m-%d+%H:%M:%S')
+                qargs[key] = val.replace(microsecond=0).isoformat()
 
         url_parts = list(urlparse.urlparse(endpoint))
-        query = dict(urlparse.parse_qsl(url_parts[4]))
-        query.update(qargs)
-        url_parts[4] = urlencode(query)
+        query = urlparse.parse_qsl(url_parts[4])
+        for key, value in qargs.items():
+            if isinstance(value, list):
+                for sub_val in value:
+                    query.append((f"{key}[]", sub_val))
+            else:
+                query.append((key, value))
+        url_parts[4] = urlparse.urlencode(query)
 
         return urlparse.urlunparse(url_parts)
 
